@@ -135,7 +135,10 @@ def endswith(check_value: Text, expect_value: Any, message: Text = ""):
 def diff(t1: Dict, t2: Dict, kwargs=None):
     if kwargs is None:
         kwargs = {}
-    info = DeepDiff(t1, t2, **kwargs)
-    if info != {}:
-        logger.error(info)
+    validate_value = kwargs.get("validate_value", False)
+    kwargs.pop("validate_value", None)
+    info = dict(DeepDiff(t1, t2, **kwargs))
+    # 不校验value
+    info.pop("values_changed", None) if not validate_value else None
+    logger.error(info) if info != {} else None
     assert info == {}
