@@ -1,8 +1,9 @@
+import datetime
 import os
 import time
 import uuid
-from datetime import datetime
 from typing import List, Dict, Text, NoReturn
+from urllib.parse import unquote
 
 try:
     import allure
@@ -32,7 +33,7 @@ from rrtv_httprunner.models import (
     TestCaseInOut,
     ProjectMeta,
     TestCase,
-    Hooks,
+    Hooks, data_enum,
 )
 
 
@@ -136,61 +137,51 @@ class HttpRunner(object):
 
     def __execute(self, aspect: Text, step: TStep, variables_mapping=None,
                   functions_mapping=None, ) -> NoReturn:
-        need_configured_attr = ["mysql", "redis", "mongo"]
-        not_need_configured_attr = ["cmd"]
-        has_attr = False
-        for attr in need_configured_attr:  # 判断是否有数据源
-            if attr in step.variables:
-                has_attr = True
-                break
+
+        def execute(opportunity):
+            for s in opportunity:
+                if data_enum.VAR_SYMBOL in s:
+                    var_name = s.split(data_enum.VAR_SYMBOL)[1]
+                    hook_content_eval = parse_data(s.split(data_enum.VAR_SYMBOL)[0], variables_mapping,
+                                                   functions_mapping)
+                    extract_mapping[var_name] = hook_content_eval
+                    variables_mapping.update(extract_mapping)
+                    logger.debug(f"assign variable: {var_name} = {hook_content_eval}")
+                else:
+                    parse_data(
+                        s, variables_mapping, functions_mapping
+                    )
+
+        need_configured_attr = data_enum.SUPPORT_TYPES
         extract_mapping = {}
+        has_attr = any(attr in step.variables for attr in need_configured_attr)  # 判断是否有数据源
+
         if aspect == "setup":
             if not has_attr:
-                for attr in not_need_configured_attr:  # 判断是否有数据源
-                    for setup in step.setup:
-                        if "&&db:" in setup:
-                            has_attr = True
-                            break
+                has_attr = any(data_enum.DB_CONFIG_SYMBOL in setup for setup in step.setup)
+            if not has_attr:
+                raise Exception("data source not found, please check configuration")
+            if has_attr is True and step.setup:
+                logger.info("setup begin execute >>>>>>")
+                execute(step.setup)
 
-            if has_attr is True:
-                if step.setup:
-                    logger.info("setup begin execute >>>>>>")
-                    for s in step.setup:
-                        if "##" in s:
-                            var_name = s.split("##")[1]
-                            hook_content_eval = parse_data(s.split("##")[0], variables_mapping,
-                                                           functions_mapping)
-                            extract_mapping[var_name] = hook_content_eval
-                            variables_mapping.update(extract_mapping)
-                            logger.debug(f"assign variable: {var_name} = {hook_content_eval}")
-                        else:
-                            parse_data(
-                                s, variables_mapping, functions_mapping
-                            )
+        if aspect == "middle":
+            if not has_attr:
+                has_attr = any(data_enum.DB_CONFIG_SYMBOL in setup for setup in step.setup)
+            if not has_attr:
+                raise Exception("data source not found, please check configuration")
+            if has_attr is True and step.execute:
+                logger.info("begin execute >>>>>>")
+                execute(step.execute)
 
         elif aspect == "teardown":
             if not has_attr:
-                for attr in not_need_configured_attr:  # 判断是否有数据源
-                    for teardown in step.teardown:
-                        if "&&db:" in teardown:
-                            has_attr = True
-                            break
-
-            if has_attr is True:
-                if step.teardown:
-                    logger.info("teardown begin execute >>>>>>")
-                    for s in step.teardown:
-                        if "##" in s:
-                            var_name = s.split("##")[1]
-                            hook_content_eval = parse_data(s.split("##")[0], variables_mapping,
-                                                           functions_mapping)
-                            extract_mapping[var_name] = hook_content_eval
-                            variables_mapping.update(extract_mapping)
-                            logger.debug(f"assign variable: {var_name} = {hook_content_eval}")
-                        else:
-                            parse_data(
-                                s, variables_mapping, functions_mapping
-                            )
+                has_attr = any(data_enum.DB_CONFIG_SYMBOL in teardown for teardown in step.teardown)
+            if not has_attr:
+                raise Exception("data source not found, please check configuration")
+            if has_attr is True and step.teardown:
+                logger.info("teardown begin execute >>>>>>")
+                execute(step.teardown)
 
     def __run_step_request(self, step: TStep) -> StepData:
         """run teststep: request"""
@@ -245,6 +236,10 @@ class HttpRunner(object):
             err_msg += f"headers: {headers}\n"
             for k, v in parsed_request_dict.items():
                 v = utils.omit_long_data(v)
+                if isinstance(v, str):
+                    v = unquote(v)
+                if isinstance(v, dict):
+                    v = {k: unquote(v) for k, v in v.items() if isinstance(v, str)}
                 err_msg += f"{k}: {repr(v)}\n"
 
             err_msg += "\n"
