@@ -74,7 +74,7 @@ class Config(object):
         self.__datasource["mysql"] = config
         return self
 
-    def redis(self, config: Union[Text, Dict]) -> "Config":
+    def redis(self, config: Union[Text, Dict, List]) -> "Config":
         self.__datasource["redis"] = config
         return self
 
@@ -376,6 +376,12 @@ class StepRequestValidation(object):
         """
         Verifies two objects are consistent
 
+        Args:
+            check_value: 检查值
+            expected_value: 预期值
+            message: 报错提示
+            validate_value: 是否校验值 Boolean类型
+
         Usage:
             >>> DeepDiff(check_value, expected_value, **kwargs)
         """
@@ -392,6 +398,14 @@ class StepRequestExtraction(object):
     def __init__(self, step_context: TStep):
         self.__step_context = step_context
 
+    def __extract__(self, db_type: Text, var: Union[Text, List], var_name: Text = None):
+        if isinstance(var, List):
+            # 指定环境场景
+            db, command = var[0], var[1]
+            self.__step_context.extract[var_name] = db_type + ":" + str(command) + "&&db:" + str(db)
+        else:
+            self.__step_context.extract[var_name] = db_type + ":" + str(var)
+
     def with_jmespath(self, jmes_path: Text, var_name: Text) -> "StepRequestExtraction":
         self.__step_context.extract[var_name] = jmes_path
         return self
@@ -425,19 +439,14 @@ class StepRequestExtraction(object):
             >>> StepRequestExtraction.with_sql(["mysql","select * from rrtv"],"mysql")
 
         """
-        if isinstance(var, List):
-            # 指定环境场景
-            db, sql = var[0], var[1]
-            self.__step_context.teardown.append("sql:" + str(sql) + "&&db:" + str(db) + "##" + var_name)
-        else:
-            self.__step_context.teardown.append("sql:" + str(var) + "##" + var_name)
+        self.__extract__("sql", var, var_name)
         return self
 
-    def with_redis(self, redis: Union[Text, List], var_name: Text = None) -> "StepRequestExtraction":
+    def with_redis(self, var: Union[Text, List], var_name: Text = None) -> "StepRequestExtraction":
         """
 
         Args:
-            redis: redis命令
+            var: redis命令
             var_name: 存储的变量名 后续通过$引用
 
         Examples:
@@ -453,21 +462,20 @@ class StepRequestExtraction(object):
             >>> StepRequestExtraction.with_redis("str_get('key')","var_name") # 直接调用api
 
         """
-        if isinstance(redis, List):
-            # 指定环境场景
-            db, cli = redis[0], redis[1]
-            self.__step_context.extract[var_name] = "redis:" + str(cli) + "&&db:" + str(db) + "##" + var_name
-        else:
-            self.__step_context.extract[var_name] = "redis:" + str(redis) + "##" + var_name
+        self.__extract__("redis", var, var_name)
         return self
 
-    def with_mongo(self, mongo: Text, var_name: Text) -> "StepRequestExtraction":
-        if isinstance(mongo, List):
-            # 指定环境场景
-            db, cli = mongo[0], mongo[1]
-            self.__step_context.extract[var_name] = "mongo:" + str(cli) + "&&db:" + str(db) + "##" + var_name
-        else:
-            self.__step_context.extract[var_name] = "mongo:" + str(mongo) + "##" + var_name
+    def with_mongo(self, var: Text, var_name: Text) -> "StepRequestExtraction":
+        """ 提取mongo数据
+
+        Args:
+            var: mongo指令
+            var_name: 存储的变量名 后续通过$引用
+
+        Returns:self
+
+        """
+        self.__extract__("mongo", var, var_name)
         return self
 
     # def with_regex(self):
@@ -596,6 +604,34 @@ class RunRequest(object):
         self.__step_context.setup.append(command)
         return self
 
+    # def execute(self, var: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
+    #     """ 在接口执行之前执行命令
+    #
+    #     Args:
+    #         var: 执行的命令
+    #         assign_var_name: 存储变量
+    #
+    #     Examples:
+    #         >>> RunRequest.execute("sql:xxx")
+    #         >>> RunRequest.execute("redis:xxx")
+    #         >>> RunRequest.execute("mongo:xxx")
+    #         >>> RunRequest.execute("cmd:xxx")
+    #
+    #     """
+    #     if isinstance(var, List):
+    #         # 指定环境场景
+    #         db, command = var[0], var[1]
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append(command + "&&db:" + str(db) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append(command + "&&db:" + str(db))
+    #     else:
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append(var + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append(var)
+    #     return self
+
     def setup_sql(self, var: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
         """ 在接口执行之前执行SQL
 
@@ -694,6 +730,101 @@ class RunRequest(object):
 
         return self
 
+    # def execute_sql(self, var: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
+    #     """ 在with_variables之后 在接口执行之前执行SQL
+    #
+    #     Args:
+    #         var: 执行SQL
+    #         assign_var_name: 变量名
+    #
+    #     Examples:
+    #         >>> RunRequest.execute_sql("select * from mysql")
+    #         >>> RunRequest.execute_sql("select * from rrtv","var_name")
+    #         >>> RunRequest.execute_sql(["mysql","select * from rrtv"])
+    #         >>> RunRequest.execute_sql(["mysql","select * from rrtv"],"var_name")
+    #     """
+    #     if isinstance(var, List):
+    #         # 指定环境场景
+    #         db, sql = var[0], var[1]
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("sql:" + str(sql) + "&&db:" + str(db) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("sql:" + str(sql) + "&&db:" + str(db))
+    #     else:
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("sql:" + str(var) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("sql:" + str(var))
+    #     return self
+    #
+    # def execute_redis(self, redis: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
+    #     """ 在with_variables之后 在接口执行之前执行redis
+    #
+    #     Args:
+    #         redis: redis命令
+    #         assign_var_name: 变量名
+    #
+    #     Examples:
+    #         >>> RunRequest.execute_redis("get('key')","var_name") # 取出键key对应的值
+    #         >>> RunRequest.execute_redis("hget('name','key')","var_name") # 取出hash的key对应的值
+    #         >>> RunRequest.execute_redis("hget('name')","var_name") # 取出hash中所有的键值对
+    #         >>> RunRequest.execute_redis("hkeys('name')","var_name") # 取出hash中所有的键值对
+    #         >>> RunRequest.execute_redis("set('key','rrtv')") # 设置key对应的值
+    #         >>> RunRequest.execute_redis("hset('name','key','value')") # name对应的hash中设置一个键值对--没有就新增，有的话就修改
+    #         >>> RunRequest.execute_redis("del('key')") # 删除指定key的键值对
+    #         >>> RunRequest.execute_redis("hdel(name, k)") # 删除hash中键值对
+    #         >>> RunRequest.execute_redis("clean") # 清空redis
+    #         >>> RunRequest.execute_redis("exists(key)") # 判断key是否存在
+    #         >>> RunRequest.execute_redis("str_get('key')","var_name") # 直接调用api
+    #
+    #     """
+    #     if isinstance(redis, List):
+    #         # 指定环境场景
+    #         db, cli = redis[0], redis[1]
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("redis:" + str(cli) + "&&db:" + str(db) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("redis:" + str(cli) + "&&db:" + str(db))
+    #     else:
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("redis:" + str(redis) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("redis:" + str(redis))
+    #     return self
+    #
+    # def execute_mongo(self, mongo: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
+    #     """在with_variables之后 在接口执行之前执行mongo
+    #     Args:
+    #         mongo: mongo命令
+    #         assign_var_name: 变量名
+    #     """
+    #     if isinstance(mongo, List):
+    #         # 指定环境场景
+    #         db, cli = mongo[0], mongo[1]
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("mongo:" + str(cli) + "&&db:" + str(db) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("mongo:" + str(cli) + "&&db:" + str(db))
+    #     else:
+    #         if assign_var_name is not None:
+    #             self.__step_context.execute.append("mongo:" + str(mongo) + "##" + assign_var_name)
+    #         else:
+    #             self.__step_context.execute.append("mongo:" + str(mongo))
+    #     return self
+    #
+    # def execute_cmd(self, command: Text) -> "RunRequest":
+    #     """ 在with_variables之后 在接口执行之前执行cmd
+    #
+    #     Args:
+    #         command: cmd命令
+    #
+    #     Examples:
+    #         >>> RunRequest.execute_cmd("echo 'Hello World !'")
+    #
+    #     """
+    #     self.__step_context.execute.append("cmd:" + command)
+    #     return self
+
     def get(self, url: Text) -> RequestWithOptionalArgs:
         self.__step_context.request = TRequest(method=MethodEnum.GET, url=url)
         return RequestWithOptionalArgs(self.__step_context)
